@@ -1,6 +1,6 @@
 # This script handles the SIP configuration and generates the Makefiles.
 #
-# Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2015 Riverbank Computing Limited <info@riverbankcomputing.com>
 #
 # This file is part of SIP.
 #
@@ -30,12 +30,13 @@ import siputils
 
 
 # Initialise the globals.
-sip_version = 0x041004
-sip_version_str = "4.16.4"
+sip_version = 0x041100
+sip_version_str = "4.17"
 py_version = sys.hexversion >> 8
 py_platform = sys.platform
 plat_py_site_dir = None
 plat_py_inc_dir = None
+plat_py_venv_inc_dir = None
 plat_py_conf_inc_dir = None
 plat_py_lib_dir = None
 plat_sip_dir = None
@@ -157,7 +158,9 @@ def set_build_platform():
     build_platform = "none"
 
     if py_platform == "win32":
-        if py_version >= 0x030300:
+        if py_version >= 0x030500:
+            build_platform = "win32-msvc2015"
+        elif py_version >= 0x030300:
             build_platform = "win32-msvc2010"
         elif py_version >= 0x020600:
             build_platform = "win32-msvc2008"
@@ -203,12 +206,13 @@ def set_platform_directories():
     """ Initialise the global variables relating to platform-specific
     directories.
     """
-    global plat_py_site_dir, plat_py_inc_dir, plat_py_conf_inc_dir
-    global plat_bin_dir, plat_py_lib_dir, plat_sip_dir
+    global plat_py_site_dir, plat_py_inc_dir, plat_py_venv_inc_dir
+    global plat_py_conf_inc_dir, plat_bin_dir, plat_py_lib_dir, plat_sip_dir
 
     # We trust distutils for some stuff.
     plat_py_site_dir = sysconfig.get_python_lib(plat_specific=1)
     plat_py_inc_dir = sysconfig.get_python_inc()
+    plat_py_venv_inc_dir = sysconfig.get_python_inc(prefix=sys.prefix)
     plat_py_conf_inc_dir = os.path.dirname(sysconfig.get_config_h_filename())
 
     if sys.platform == "win32":
@@ -453,12 +457,15 @@ macx {
     else:
         sipconfig.inform("Creating sip module Makefile...")
 
-        sipconfig.ModuleMakefile(
+        build_dir = os.getcwd()
+
+        makefile = sipconfig.ModuleMakefile(
             configuration=cfg,
-            build_file=os.path.join(src_dir, "siplib", "siplib.sbf"),
+            build_file=os.path.join(build_dir, "siplib", "siplib.sbf"),
             dir="siplib",
             install_dir=cfg.sip_mod_dir,
-            installs=([os.path.join(src_dir, "siplib", "sip.h")], cfg.sip_inc_dir),
+            installs=([os.path.join(build_dir, "siplib", "sip.h")],
+                    cfg.sip_inc_dir),
             console=1,
             warnings=0,
             static=opts.static,
@@ -466,7 +473,14 @@ macx {
             universal=opts.universal,
             arch=opts.arch,
             deployment_target=opts.deployment_target
-        ).generate()
+        )
+        
+        if src_dir != build_dir:
+            src_siplib_dir = os.path.join(src_dir, "siplib")
+            makefile.extra_include_dirs.append(src_siplib_dir)
+            makefile.extra_source_dirs.append(src_siplib_dir)
+
+        makefile.generate()
 
 
 def get_sources(sources_dir, ext):
@@ -606,7 +620,7 @@ def create_optparser(sdk_dir):
         setattr(parser.values, option.dest, os.path.abspath(value))
 
     def store_version(option, opt_str, value, parser):
-        version = version_from_string(value)
+        version = siputils.version_from_string(value)
         if version is None:
             raise optparse.OptionValueError(
                     "'%s' is not a valid version number" % value)
@@ -694,7 +708,7 @@ def create_optparser(sdk_dir):
     g.add_option("-e", "--incdir", action="callback", type="string",
             metavar="DIR", dest="sipincdir", callback=store_abspath,
             help="where the SIP header file will be installed [default: "
-                    "%s]" % plat_py_inc_dir)
+                    "%s]" % plat_py_venv_inc_dir)
     g.add_option("-v", "--sipdir", action="callback", type="string",
             metavar="DIR", dest="sipsipdir", callback=store_abspath,
             help="where .sip files are normally installed [default: "
@@ -794,7 +808,7 @@ def main(argv):
 
     # Set defaults.
     sip_bin_dir = plat_bin_dir
-    sip_inc_dir = plat_py_inc_dir
+    sip_inc_dir = plat_py_venv_inc_dir
     sip_module_dir = plat_py_site_dir
     sip_sip_dir = plat_sip_dir
 
