@@ -1,7 +1,7 @@
 /*
  * This file implements the API for the array type.
  *
- * Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+ * Copyright (c) 2015 Riverbank Computing Limited <info@riverbankcomputing.com>
  *
  * This file is part of SIP.
  *
@@ -199,11 +199,18 @@ static PySequenceMethods sipArray_SequenceMethods = {
     0,                      /* sq_concat */
     0,                      /* sq_repeat */
     sipArray_item,          /* sq_item */
-#if PY_VERSION_HEX < 0x02050000
+#if PY_VERSION_HEX >= 0x02050000
+    0,                      /* sq_slice */
+    0,                      /* sq_ass_item */
+    0,                      /* sq_ass_slice */
+#else
     sipArray_slice,         /* sq_slice */
     sipArray_ass_item,      /* sq_ass_item */
     sipArray_ass_slice,     /* sq_ass_slice */
 #endif
+    0,                      /* sq_contains */
+    0,                      /* sq_inplace_concat */
+    0,                      /* sq_inplace_repeat */
 };
 
 
@@ -334,7 +341,7 @@ static int sipArray_getbuffer(PyObject *self, Py_buffer *view, int flags)
 
     if (((flags & PyBUF_WRITABLE) == PyBUF_WRITABLE) && (array->flags & SIP_READ_ONLY))
     {
-        PyErr_SetString(PyExc_BufferError, "Object is not writable.");
+        PyErr_SetString(PyExc_BufferError, "object is not writable.");
         return -1;
     }
 
@@ -348,11 +355,7 @@ static int sipArray_getbuffer(PyObject *self, Py_buffer *view, int flags)
 
     view->format = NULL;
     if ((flags & PyBUF_FORMAT) == PyBUF_FORMAT)
-#if PY_MAJOR_VERSION >= 3
-        view->format = array->format;
-#else
         view->format = (char *)array->format;
-#endif
 
     view->ndim = 1;
 
@@ -468,7 +471,7 @@ PyTypeObject sipArray_Type = {
     "sip.array",            /* tp_name */
     sizeof (sipArrayObject),    /* tp_basicsize */
     0,                      /* tp_itemsize */
-    0,                      /* tp_dealloc */
+    sipArray_dealloc,       /* tp_dealloc */
     0,                      /* tp_print */
     0,                      /* tp_getattr */
     0,                      /* tp_setattr */
@@ -510,6 +513,20 @@ PyTypeObject sipArray_Type = {
     0,                      /* tp_init */
     0,                      /* tp_alloc */
     0,                      /* tp_new */
+    0,                      /* tp_free */
+    0,                      /* tp_is_gc */
+    0,                      /* tp_bases */
+    0,                      /* tp_mro */
+    0,                      /* tp_cache */
+    0,                      /* tp_subclasses */
+    0,                      /* tp_weaklist */
+    0,                      /* tp_del */
+#if PY_VERSION_HEX >= 0x02060000
+    0,                      /* tp_version_tag */
+#endif
+#if PY_VERSION_HEX >= 0x03040000
+    0,                      /* tp_finalize */
+#endif
 };
 
 
@@ -616,22 +633,22 @@ static void *get_value(sipArrayObject *array, PyObject *value)
         switch (*array->format)
         {
         case 'b':
-            static_data.s_char_t = SIPLong_AsLong(value);
+            static_data.s_char_t = (signed char)SIPLong_AsLong(value);
             data = &static_data.s_char_t;
             break;
 
         case 'B':
-            static_data.u_char_t = sip_api_long_as_unsigned_long(value);
+            static_data.u_char_t = (unsigned char)sip_api_long_as_unsigned_long(value);
             data = &static_data.u_char_t;
             break;
 
         case 'h':
-            static_data.s_short_t = SIPLong_AsLong(value);
+            static_data.s_short_t = (signed short)SIPLong_AsLong(value);
             data = &static_data.s_short_t;
             break;
 
         case 'H':
-            static_data.u_short_t = sip_api_long_as_unsigned_long(value);
+            static_data.u_short_t = (unsigned short)sip_api_long_as_unsigned_long(value);
             data = &static_data.u_short_t;
             break;
 
@@ -646,7 +663,7 @@ static void *get_value(sipArrayObject *array, PyObject *value)
             break;
 
         case 'f':
-            static_data.float_t = PyFloat_AsDouble(value);
+            static_data.float_t = (float)PyFloat_AsDouble(value);
             data = &static_data.float_t;
             break;
 
